README for HyperPipe code

The Makefile contains commands for running this HyperPipe code for a sample Gaussian distribution, and instructions for how the makefile can be modified for a new user supplied code run.
For more details, see  the auto-generated documentation [here](https://rift-documentation.readthedocs.io/en/latest/hyperpipe.html) for a description of hyperpipe.


Similar content is also available in the supplementary document 'technical_doc.txt' for a pedagogical overview of the proceedure and implementation of the pipeline.

